from tkinter.constants import *

DEFAULT = 'default'
DEFAULT_THEME = 'litera'
TTK_CLAM = 'clam'
TTK_ALT = 'alt'
TTK_DEFAULT = 'default'

# meter constants
FULL = 'full'
SEMI = 'semi'

# progressbar constant
DETERMINATE = 'determinate'
INDETERMINATE = 'indeterminate'

# bootstyle colors
PRIMARY = 'primary'
SECONDARY = 'secondary'
SUCCESS = 'success'
DANGER = 'danger'
WARNING = 'warning'
INFO = 'info'
LIGHT = 'light'
DARK = 'dark'

# bootstyle types
OUTLINE = 'outline'
LINK = 'link'
TOGGLE = 'toggle'
INVERSE = 'inverse'
STRIPED = 'striped'
TOOLBUTTON = 'toolbutton'
ROUND = 'round'
SQUARE = 'square'

# treeview constants
TREE = 'tree'
HEADINGS = 'headings'
TREEHEADINGS = 'tree headings'

# state constants
READONLY = 'readonly'